@@ -21,7 +21,10 @@ class SIGMOID:
     return np.maximum(X,0)
 
   def d(self, Y):
-    result = self.predict(Y)*(1-self.predict(Y))
+    # result = self.predict(Y)*(1-self.predict(Y))
+    # return result
+
+    result = np.ones(Y.shape)
     return result
 
   def __str__(self):
